@@ -43,7 +43,7 @@ class EndpointTraceTest(unittest.TestCase):
                 tags={'k3': 'v33', 'k4': 4.0})
             trace.set_tag('k5', 'v5')
             trace.set_param('p2', 'v2')
-            trace.set_data('input', np.asarray([[1, 2],[3, 4]]), extra_counts=dict(c1=1, c2=2))
+            trace.set_data('input', np.asarray([[1, 2],[3, 4]]), counts=dict(c1=1, c2=2))
             time.sleep(0.01)
             trace.stop()
 
@@ -82,7 +82,6 @@ class EndpointTraceTest(unittest.TestCase):
         self.assertEqual(signal.params[1].name, 'p2')
         self.assertEqual(signal.params[1].value, 'v2')
         self.assertTrue(signal.params[1].is_trace_level)
-        self.assertEqual(signal.trace_sample.trace_idx, 10)
         self.assertTrue(signal.trace_sample.latency_us > 0)
         self.assertEqual(signal.data_profile[0].data_name, 'input')
         self.assertEqual(signal.data_profile[0].shape, [2, 2])
