@@ -25,6 +25,7 @@ class XGBoostRecorderTest(unittest.TestCase):
         graphsignal.configure(
             api_key='k1',
             deployment='d1',
+            upload_on_shutdown=False,
             debug_mode=True)
 
     def tearDown(self):
@@ -39,8 +40,6 @@ class XGBoostRecorderTest(unittest.TestCase):
         recorder.on_trace_stop(signal, context, DEFAULT_OPTIONS)
         recorder.on_trace_read(signal, context, DEFAULT_OPTIONS)
 
-        self.assertEqual(
-            signal.frameworks[0].type,
-            signals_pb2.FrameworkInfo.FrameworkType.XGBOOST_FRAMEWORK)
+        self.assertEqual(signal.frameworks[0].name, 'XGBoost')
 
         self.assertTrue(len(signal.frameworks[0].params) > 0)
